==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/VerticalAnchoredCategorySeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AnchoredCategorySeriesDescriptionMetadata } from "./AnchoredCategorySeriesDescriptionMetadata";
/**
 * @hidden
 */
var VerticalAnchoredCategorySeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(VerticalAnchoredCategorySeriesDescriptionMetadata, _super);
    function VerticalAnchoredCategorySeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    VerticalAnchoredCategorySeriesDescriptionMetadata.b = function (a) {
        if (VerticalAnchoredCategorySeriesDescriptionMetadata.a == null) {
            VerticalAnchoredCategorySeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            VerticalAnchoredCategorySeriesDescriptionMetadata.c(VerticalAnchoredCategorySeriesDescriptionMetadata.a);
        }
        if (a.g(VerticalAnchoredCategorySeriesDescriptionMetadata.a)) {
            return;
        }
        a.s(VerticalAnchoredCategorySeriesDescriptionMetadata.a);
    };
    VerticalAnchoredCategorySeriesDescriptionMetadata.c = function (a) {
        AnchoredCategorySeriesDescriptionMetadata.c(a);
        a.item("XAxisRef", "(w:XAxis,wf:XAxis)DataRef::object");
        a.item("XAxisRef@nameBinding", "true");
        a.item("YAxisRef", "(w:YAxis,wf:YAxis)DataRef::object");
        a.item("YAxisRef@nameBinding", "true");
    };
    VerticalAnchoredCategorySeriesDescriptionMetadata.d = function (a) {
        VerticalAnchoredCategorySeriesDescriptionMetadata.b(a);
        a.t("VerticalAnchoredCategorySeries", VerticalAnchoredCategorySeriesDescriptionMetadata.a);
    };
    VerticalAnchoredCategorySeriesDescriptionMetadata.$t = markType(VerticalAnchoredCategorySeriesDescriptionMetadata, 'VerticalAnchoredCategorySeriesDescriptionMetadata');
    VerticalAnchoredCategorySeriesDescriptionMetadata.a = null;
    return VerticalAnchoredCategorySeriesDescriptionMetadata;
}(Base));
export { VerticalAnchoredCategorySeriesDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/VerticalAnchoredCategorySeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AnchoredCategorySeriesDescriptionMetadata } from "./AnchoredCategorySeriesDescriptionMetadata";
/**
 * @hidden
 */
var VerticalAnchoredCategorySeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(VerticalAnchoredCategorySeriesDescriptionMetadata, _super);
    function VerticalAnchoredCategorySeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    VerticalAnchoredCategorySeriesDescriptionMetadata.b = function (a) {
        if (VerticalAnchoredCategorySeriesDescriptionMetadata.a == null) {
            VerticalAnchoredCategorySeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            VerticalAnchoredCategorySeriesDescriptionMetadata.c(VerticalAnchoredCategorySeriesDescriptionMetadata.a);
        }
        if (a.j(VerticalAnchoredCategorySeriesDescriptionMetadata.a)) {
            return;
        }
        a.y(VerticalAnchoredCategorySeriesDescriptionMetadata.a);
    };
    VerticalAnchoredCategorySeriesDescriptionMetadata.c = function (a) {
        AnchoredCategorySeriesDescriptionMetadata.c(a);
        a.item("XAxisRef", "(w:XAxis,wf:XAxis)DataRef::object");
        a.item("XAxisRef@nameBinding", "true");
        a.item("YAxisRef", "(w:YAxis,wf:YAxis)DataRef::object");
        a.item("YAxisRef@nameBinding", "true");
    };
    VerticalAnchoredCategorySeriesDescriptionMetadata.d = function (a) {
        VerticalAnchoredCategorySeriesDescriptionMetadata.b(a);
        a.z("VerticalAnchoredCategorySeries", VerticalAnchoredCategorySeriesDescriptionMetadata.a);
    };
    VerticalAnchoredCategorySeriesDescriptionMetadata.$t = markType(VerticalAnchoredCategorySeriesDescriptionMetadata, 'VerticalAnchoredCategorySeriesDescriptionMetadata');
    VerticalAnchoredCategorySeriesDescriptionMetadata.a = null;
    return VerticalAnchoredCategorySeriesDescriptionMetadata;
}(Base));
export { VerticalAnchoredCategorySeriesDescriptionMetadata };
